"""Top-level package for medimtools."""

__author__ = """Suraj Pai"""
__email__ = "b.pai@maastrichtuniversity.nl"
__version__ = "0.1.1"
